==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mozilla/XMozillaBootstrap.hpp <==
#ifndef _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_
#define _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HDL_
#include "com/sun/star/mozilla/XMozillaBootstrap.hdl"
#endif

#ifndef _COM_SUN_STAR_MOZILLA_XPROFILEMANAGER_HPP_
#include "com/sun/star/mozilla/XProfileManager.hpp"
#endif
#ifndef _COM_SUN_STAR_MOZILLA_XPROFILEDISCOVER_HPP_
#include "com/sun/star/mozilla/XProfileDiscover.hpp"
#endif
#ifndef _COM_SUN_STAR_MOZILLA_XPROXYRUNNER_HPP_
#include "com/sun/star/mozilla/XProxyRunner.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::mozilla::XMozillaBootstrap >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.mozilla.XMozillaBootstrap" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::mozilla::XMozillaBootstrap::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::mozilla::XMozillaBootstrap > * >(0));
}

#endif // _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mozilla/XMozillaBootstrap.hpp <==
#ifndef _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_
#define _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HDL_
#include "com/sun/star/mozilla/XMozillaBootstrap.hdl"
#endif

#ifndef _COM_SUN_STAR_MOZILLA_XPROFILEMANAGER_HPP_
#include "com/sun/star/mozilla/XProfileManager.hpp"
#endif
#ifndef _COM_SUN_STAR_MOZILLA_XPROFILEDISCOVER_HPP_
#include "com/sun/star/mozilla/XProfileDiscover.hpp"
#endif
#ifndef _COM_SUN_STAR_MOZILLA_XPROXYRUNNER_HPP_
#include "com/sun/star/mozilla/XProxyRunner.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace mozilla {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::mozilla::XMozillaBootstrap const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.mozilla.XMozillaBootstrap" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::mozilla::XMozillaBootstrap > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::mozilla::XMozillaBootstrap > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::mozilla::XMozillaBootstrap::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::mozilla::XMozillaBootstrap > * >(0));
}

#endif // _COM_SUN_STAR_MOZILLA_XMOZILLABOOTSTRAP_HPP_
